using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using System.Collections;

namespace WinGrid_Summary_GroupByComparer_CS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            // Store some objects we will need to use repeatedly. 
            UltraGridLayout layout = e.Layout;
            UltraGridBand rootBand = layout.Bands[0];            

            // Put the GroupByRow Summaries into cells. This just makes them easier to read.
            layout.Override.GroupBySummaryDisplayStyle = GroupBySummaryDisplayStyle.SummaryCells;

            // Allow GroupBy in the grid. 
            layout.ViewStyleBand = ViewStyleBand.OutlookGroupBy;

            // Assign an instance of the GroupByComparer to the Shape column. This means that
            // when grouping by Shape, the comparer will be used to sort the rows. 
            rootBand.Columns["Shape"].GroupByComparer = new PriceSummaryGroupByComparer();

            // Group by the Shape column. 
            rootBand.SortedColumns.Add("Shape", false, true);

            // Add a summary for the Price column.
            SummarySettings summarySettings = rootBand.Summaries.Add("PriceSum", SummaryType.Sum, rootBand.Columns["Price"]);
            
            // Make the summary display just the value with no extra formatting. 
            summarySettings.DisplayFormat = "{0}";

            // Make the summary yellow so it's easier to see. 
            summarySettings.GroupBySummaryValueAppearance.BackColor = Color.Yellow;            
        }
    }

    public class PriceSummaryGroupByComparer : IComparer
    {
        #region IComparer Members

        int IComparer.Compare(object x, object y)
        {
            // Get the two objects as UltraGridGroupByRows
            UltraGridGroupByRow groupByRowX = (UltraGridGroupByRow)x;
            UltraGridGroupByRow groupByRowY = (UltraGridGroupByRow)y;

            // Get the Sum of the price for each row. 
            decimal priceX = (decimal)groupByRowX.Rows.SummaryValues["PriceSum"].Value;
            decimal priceY = (decimal)groupByRowY.Rows.SummaryValues["PriceSum"].Value;

            // If the prices are different, then just return the Compare result of the
            // two prices. 
            int result = priceX.CompareTo(priceY);
            if (result != 0)
                return result;

            // Fall back to sorting by the index of the rows. This will keep the sorting 
            // consistent when there are duplicate values. 
            return groupByRowX.Index.CompareTo(groupByRowY.Index);
        }

        #endregion
    }
}